@@ -7,7 +7,7 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"path"
+	"path/filepath"
 	"strings"
 
 	"github.com/antchfx/xmlquery"
@@ -28,9 +28,12 @@ func NewRootCmd() *cobra.Command {
 		SilenceUsage: true,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
-			var reader io.Reader
+			var readers []io.Reader
+			var fileNames []string
 			var indent string
 
+			inPlace, _ := cmd.Flags().GetBool("in-place")
+
 			if indent, err = getIndent(cmd.Flags()); err != nil {
 				return err
 			}
@@ -42,11 +45,19 @@ func NewRootCmd() *cobra.Command {
 					return nil
 				}
 
-				reader = os.Stdin
+				readers = append(readers, os.Stdin)
 			} else {
-				var err error
-				if reader, err = os.Open(args[len(args)-1]); err != nil {
-					return err
+				for _, fileName := range args {
+					fileNames = append(fileNames, fileName)
+					f, err := os.Open(fileName)
+					if err != nil {
+						return err
+					}
+					defer func() {
+						_ = f.Close()
+					}()
+
+					readers = append(readers, f)
 				}
 			}
 
@@ -67,52 +78,65 @@ func NewRootCmd() *cobra.Command {
 			}
 			jsonOutputMode, _ := cmd.Flags().GetBool("json")
 
+			if (xPathQuery != "" || cssQuery != "") && inPlace {
+				return errors.New("in-place formatting is incompatible with nodes selection")
+			}
+
 			pr, pw := io.Pipe()
-			errChan := make(chan error, 1)
 
-			go func() {
-				defer close(errChan)
-				defer pw.Close()
+			if inPlace {
+				for i := range len(fileNames) {
+					var content []byte
+					fileName := fileNames[i]
+					reader := readers[i]
+					pr, pw := io.Pipe()
 
-				var err error
-				if xPathQuery != "" {
-					err = utils.XPathQuery(reader, pw, xPathQuery, singleNode, options)
-				} else if cssQuery != "" {
-					err = utils.CSSQuery(reader, pw, cssQuery, cssAttr, options)
-				} else {
-					var contentType utils.ContentType
-					contentType, reader = detectFormat(cmd.Flags(), reader)
-					if jsonOutputMode {
-						err = processAsJSON(cmd.Flags(), reader, pw, contentType)
-					} else {
-						switch contentType {
-						case utils.ContentHtml:
-							err = utils.FormatHtml(reader, pw, indent, colors)
-						case utils.ContentXml:
-							err = utils.FormatXml(reader, pw, indent, colors)
-						case utils.ContentJson:
-							err = utils.FormatJson(reader, pw, indent, colors)
-						default:
-							err = fmt.Errorf("unknown content type: %v", contentType)
-						}
+					go func() {
+						err := processContent(reader, pw, cmd.Flags(), jsonOutputMode, indent, colors)
+						_ = pw.CloseWithError(err)
+					}()
+
+					if content, err = io.ReadAll(pr); err != nil {
+						return err
+					}
+
+					if err = os.WriteFile(fileName, content, 0600); err != nil {
+						return err
 					}
 				}
 
-				errChan <- err
-			}()
-
-			if err := utils.PagerPrint(pr, cmd.OutOrStdout()); err != nil {
-				return err
+				return nil
 			}
 
-			return <-errChan
+			go func() {
+				defer func() {
+					_ = pw.Close()
+				}()
+
+				for _, reader := range readers {
+					if xPathQuery != "" {
+						err = utils.XPathQuery(reader, pw, xPathQuery, singleNode, options)
+					} else if cssQuery != "" {
+						err = utils.CSSQuery(reader, pw, cssQuery, cssAttr, options)
+					} else {
+						err = processContent(reader, pw, cmd.Flags(), jsonOutputMode, indent, colors)
+					}
+				}
+
+				if err != nil {
+					fmt.Println("Error:", err)
+					os.Exit(1)
+				}
+			}()
+
+			return utils.PagerPrint(pr, cmd.OutOrStdout())
 		},
 	}
 }
 
 func InitFlags(cmd *cobra.Command) {
 	homeDir, _ := os.UserHomeDir()
-	configFile := path.Join(homeDir, ".xq")
+	configFile := filepath.Join(homeDir, ".xq")
 	if err := utils.LoadConfig(configFile); err != nil {
 		fmt.Printf("Error while reading the config file: %v\n", err)
 		os.Exit(1)
@@ -140,6 +164,7 @@ func InitFlags(cmd *cobra.Command) {
 	cmd.PersistentFlags().BoolP("json", "j", false, "Output the result as JSON")
 	cmd.PersistentFlags().Bool("compact", false, "Compact JSON output (no indentation)")
 	cmd.PersistentFlags().IntP("depth", "d", -1, "Maximum nesting depth for JSON output (-1 for unlimited)")
+	cmd.PersistentFlags().BoolP("in-place", "i", false, "Format file in place")
 }
 
 func Execute() {
@@ -185,6 +210,11 @@ func getXpathQuery(flags *pflag.FlagSet) (query string, single bool) {
 }
 
 func getColorMode(flags *pflag.FlagSet) int {
+	inPlace, _ := flags.GetBool("in-place")
+	if inPlace {
+		return utils.ColorsDisabled
+	}
+
 	colors := utils.ColorsDefault
 
 	disableColors, _ := flags.GetBool("no-color")
@@ -225,6 +255,30 @@ func detectFormat(flags *pflag.FlagSet, origReader io.Reader) (utils.ContentType
 	return utils.ContentXml, reader
 }
 
+func processContent(reader io.Reader, pw io.Writer, flags *pflag.FlagSet, jsonOutputMode bool, indent string, colors int) error {
+	var err error
+	var contentType utils.ContentType
+
+	contentType, reader = detectFormat(flags, reader)
+
+	if jsonOutputMode {
+		err = processAsJSON(flags, reader, pw, contentType)
+	} else {
+		switch contentType {
+		case utils.ContentHtml:
+			err = utils.FormatHtml(reader, pw, indent, colors)
+		case utils.ContentXml:
+			err = utils.FormatXml(reader, pw, indent, colors)
+		case utils.ContentJson:
+			err = utils.FormatJson(reader, pw, indent, colors)
+		default:
+			err = fmt.Errorf("unknown content type: %v", contentType)
+		}
+	}
+
+	return err
+}
+
 func processAsJSON(flags *pflag.FlagSet, reader io.Reader, w io.Writer, contentType utils.ContentType) error {
 	var (
 		jsonCompact bool
