@@ -1,22 +1,23 @@
 package utils
 
 import (
-	"github.com/stretchr/testify/assert"
-	"path"
+	"path/filepath"
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 func TestLoadConfig(t *testing.T) {
 	var err error
 	var config ConfigOptions
 
-	err = LoadConfig(path.Join("..", "..", "test", "data", "config", "config1"))
+	err = LoadConfig(filepath.Join("..", "..", "test", "data", "config", "config1"))
 	assert.Nil(t, err)
 	config = GetConfig()
 	assert.Equal(t, config.Indent, 8)
 	assert.Equal(t, config.NoColor, true)
 
-	err = LoadConfig(path.Join("..", "..", "test", "data", "config", "config2"))
+	err = LoadConfig(filepath.Join("..", "..", "test", "data", "config", "config2"))
 	assert.Nil(t, err)
 	config = GetConfig()
 	assert.Equal(t, config.Indent, 2)
